==> vectorz-0.6.3-sources.jar: mikera/transformz/impl/IdentityTranslation.java <==
package mikera.transformz.impl;

import mikera.matrixx.AMatrix;
import mikera.matrixx.Matrixx;
import mikera.transformz.ATranslation;
import mikera.vectorz.AVector;
import mikera.vectorz.Tools;
import mikera.vectorz.Vectorz;

/**
 * Immutable identity translation
 * 
 * @author Mike
 *
 */
public final class IdentityTranslation extends ATranslation {
	private static final int INSTANCE_COUNT=6;

	private final int dimensions;
	
	private IdentityTranslation(int dims) {
		this.dimensions=dims;
	}
	
	private static final  IdentityTranslation[] INSTANCES=new IdentityTranslation[INSTANCE_COUNT];
	static {
		for (int i=0; i<INSTANCE_COUNT; i++) {
			INSTANCES[i]=new IdentityTranslation(i);
		}
	}
	
	public static IdentityTranslation create(int i) {
		if (i<INSTANCE_COUNT) return INSTANCES[i];
		return new IdentityTranslation(i);
	}

	@Override
	public AMatrix getMatrixComponent() {
		return Matrixx.createImmutableIdentityMatrix(dimensions);
	}

	@Override
	public ATranslation getTranslationComponent() {
		return this;
	}

	@Override
	public void transform(AVector source, AVector dest) {
		dest.set(source);		
	}
	
	@Override
	public AVector transform(AVector source) {
		return source.clone();		
	}
	
	@Override
	public void transformInPlace(AVector v) {
		// no change!
	}
	
	@Override
	public double calculateComponent(int i, AVector v) {
		return v.get(i);
	}
	
	@Override
	public boolean isIdentity() {
		return true;
	}

	@Override
	public int inputDimensions() {
		return dimensions;
	}

	@Override
	public int outputDimensions() {
		return dimensions;
	}

	@Override
	public AVector getTranslationVector() {
		return Vectorz.immutableZeroVector(dimensions);
	}
	
	@Override 
	public int hashCode() {
		return Tools.zeroVectorHash(dimensions);
	}
}

==> vectorz-0.9.0-sources.jar: mikera/transformz/impl/IdentityTranslation.java <==
package mikera.transformz.impl;

import mikera.matrixx.AMatrix;
import mikera.matrixx.Matrixx;
import mikera.transformz.ATranslation;
import mikera.vectorz.AVector;
import mikera.vectorz.Tools;
import mikera.vectorz.Vectorz;

/**
 * Immutable identity translation
 * 
 * @author Mike
 *
 */
public final class IdentityTranslation extends ATranslation {
	private static final int INSTANCE_COUNT=6;

	private final int dimensions;
	
	private IdentityTranslation(int dims) {
		this.dimensions=dims;
	}
	
	private static final  IdentityTranslation[] INSTANCES=new IdentityTranslation[INSTANCE_COUNT];
	static {
		for (int i=0; i<INSTANCE_COUNT; i++) {
			INSTANCES[i]=new IdentityTranslation(i);
		}
	}
	
	public static IdentityTranslation create(int i) {
		if (i<INSTANCE_COUNT) return INSTANCES[i];
		return new IdentityTranslation(i);
	}

	@Override
	public AMatrix getMatrixComponent() {
		return Matrixx.createImmutableIdentityMatrix(dimensions);
	}

	@Override
	public ATranslation getTranslationComponent() {
		return this;
	}

	@Override
	public void transform(AVector source, AVector dest) {
		dest.set(source);		
	}
	
	@Override
	public AVector transform(AVector source) {
		return source.clone();		
	}
	
	@Override
	public void transformInPlace(AVector v) {
		// no change!
	}
	
	@Override
	public double calculateElement(int i, AVector v) {
		return v.get(i);
	}
	
	@Override
	public boolean isIdentity() {
		return true;
	}

	@Override
	public int inputDimensions() {
		return dimensions;
	}

	@Override
	public int outputDimensions() {
		return dimensions;
	}

	@Override
	public AVector getTranslationVector() {
		return Vectorz.immutableZeroVector(dimensions);
	}
	
	@Override 
	public int hashCode() {
		return Tools.zeroVectorHash(dimensions);
	}
}
